==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hardwaresecuritymodules/kotlin/inputs/ApiEntityReferenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hardwaresecuritymodules.kotlin.inputs

import com.pulumi.azurenative.hardwaresecuritymodules.inputs.ApiEntityReferenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The API entity reference.
 * @property id The ARM resource id in the form of /subscriptions/{SubscriptionId}/resourceGroups/{ResourceGroupName}/...
 */
public data class ApiEntityReferenceArgs(
    public val id: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hardwaresecuritymodules.inputs.ApiEntityReferenceArgs> {
    override fun toJava():
        com.pulumi.azurenative.hardwaresecuritymodules.inputs.ApiEntityReferenceArgs =
        com.pulumi.azurenative.hardwaresecuritymodules.inputs.ApiEntityReferenceArgs.builder()
            .id(id?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApiEntityReferenceArgs].
 */
@PulumiTagMarker
public class ApiEntityReferenceArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value The ARM resource id in the form of /subscriptions/{SubscriptionId}/resourceGroups/{ResourceGroupName}/...
     */
    @JvmName("oixricrvmcavgrri")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The ARM resource id in the form of /subscriptions/{SubscriptionId}/resourceGroups/{ResourceGroupName}/...
     */
    @JvmName("jqrowqrkirjociyo")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): ApiEntityReferenceArgs = ApiEntityReferenceArgs(
        id = id,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hardwaresecuritymodules/kotlin/inputs/ApiEntityReferenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hardwaresecuritymodules.kotlin.inputs

import com.pulumi.azurenative.hardwaresecuritymodules.inputs.ApiEntityReferenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The API entity reference.
 * @property id The ARM resource id in the form of /subscriptions/{SubscriptionId}/resourceGroups/{ResourceGroupName}/...
 */
public data class ApiEntityReferenceArgs(
    public val id: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hardwaresecuritymodules.inputs.ApiEntityReferenceArgs> {
    override fun toJava():
        com.pulumi.azurenative.hardwaresecuritymodules.inputs.ApiEntityReferenceArgs =
        com.pulumi.azurenative.hardwaresecuritymodules.inputs.ApiEntityReferenceArgs.builder()
            .id(id?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApiEntityReferenceArgs].
 */
@PulumiTagMarker
public class ApiEntityReferenceArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value The ARM resource id in the form of /subscriptions/{SubscriptionId}/resourceGroups/{ResourceGroupName}/...
     */
    @JvmName("fqaccyepkochhyav")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The ARM resource id in the form of /subscriptions/{SubscriptionId}/resourceGroups/{ResourceGroupName}/...
     */
    @JvmName("afucipewbgyjwyfi")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): ApiEntityReferenceArgs = ApiEntityReferenceArgs(
        id = id,
    )
}
